@@ -236,6 +236,29 @@ TEST(MsgsTest, ConvertMathMassMatrix3ToMsgs)
   EXPECT_EQ(ignition::math::Pose3d::Zero, msgs::Convert(msg.pose()));
 }
 
+/////////////////////////////////////////////////
+TEST(MsgsTest, ConvertMathSphericalCoordinatesToMsgs)
+{
+  auto msg = msgs::Convert(
+      math::SphericalCoordinates(
+      math::SphericalCoordinates::SurfaceType::EARTH_WGS84,
+      IGN_DTOR(1.1), IGN_DTOR(2.2), 3.3, IGN_DTOR(0.4)));
+
+  EXPECT_EQ(msgs::SphericalCoordinates::EARTH_WGS84, msg.surface_model());
+  EXPECT_DOUBLE_EQ(1.1, msg.latitude_deg());
+  EXPECT_DOUBLE_EQ(2.2, msg.longitude_deg());
+  EXPECT_DOUBLE_EQ(3.3, msg.elevation());
+  EXPECT_DOUBLE_EQ(0.4, msg.heading_deg());
+
+  auto math = msgs::Convert(msg);
+
+  EXPECT_EQ(math::SphericalCoordinates::EARTH_WGS84, math.Surface());
+  EXPECT_DOUBLE_EQ(1.1, math.LatitudeReference().Degree());
+  EXPECT_DOUBLE_EQ(2.2, math.LongitudeReference().Degree());
+  EXPECT_DOUBLE_EQ(3.3, math.ElevationReference());
+  EXPECT_DOUBLE_EQ(0.4, math.HeadingOffset().Degree());
+}
+
 /////////////////////////////////////////////////
 TEST(UtilityTest, ConvertStringMsg)
 {
@@ -316,6 +339,24 @@ TEST(UtilityTest, ConvertFloat)
   EXPECT_DOUBLE_EQ(s, 0.999f);
 }
 
+/////////////////////////////////////////////////
+TEST(UtilityTest, ConvertTimePoint)
+{
+  std::chrono::steady_clock::duration timePoint =
+    std::chrono::steady_clock::duration::zero();
+  msgs::Time msg = msgs::Convert(timePoint);
+  EXPECT_EQ(0, msg.sec());
+  EXPECT_EQ(0, msg.nsec());
+
+  std::chrono::steady_clock::duration s = msgs::Convert(msg);
+  EXPECT_EQ(s, std::chrono::steady_clock::duration::zero());
+
+  timePoint = std::chrono::seconds(200) + std::chrono::nanoseconds(999);
+  msg = msgs::Convert(timePoint);
+  EXPECT_EQ(200, msg.sec());
+  EXPECT_EQ(999, msg.nsec());
+}
+
 /////////////////////////////////////////////////
 TEST(UtilityTest, SetVector3)
 {
@@ -433,6 +474,21 @@ TEST(MsgsTest, SetMassMatrix3)
   EXPECT_EQ(ignition::math::Pose3d::Zero, msgs::Convert(msg.pose()));
 }
 
+/////////////////////////////////////////////////
+TEST(MsgsTest, SetSphericalCoordinates)
+{
+  msgs::SphericalCoordinates msg;
+  msgs::Set(&msg, math::SphericalCoordinates(
+      math::SphericalCoordinates::SurfaceType::EARTH_WGS84,
+      IGN_DTOR(1.1), IGN_DTOR(2.2), 3.3, IGN_DTOR(0.4)));
+
+  EXPECT_EQ(msgs::SphericalCoordinates::EARTH_WGS84, msg.surface_model());
+  EXPECT_DOUBLE_EQ(1.1, msg.latitude_deg());
+  EXPECT_DOUBLE_EQ(2.2, msg.longitude_deg());
+  EXPECT_DOUBLE_EQ(3.3, msg.elevation());
+  EXPECT_DOUBLE_EQ(0.4, msg.heading_deg());
+}
+
 /////////////////////////////////////////////////
 TEST(MsgsTest, SetStringMsg)
 {
@@ -559,7 +615,9 @@ TEST(MsgsTest, ConvertMsgsGeometryTypeToString)
 {
   CompareMsgsGeometryTypeToString(msgs::Geometry::BOX);
   CompareMsgsGeometryTypeToString(msgs::Geometry::SPHERE);
+  CompareMsgsGeometryTypeToString(msgs::Geometry::CAPSULE);
   CompareMsgsGeometryTypeToString(msgs::Geometry::CYLINDER);
+  CompareMsgsGeometryTypeToString(msgs::Geometry::ELLIPSOID);
   CompareMsgsGeometryTypeToString(msgs::Geometry::PLANE);
   CompareMsgsGeometryTypeToString(msgs::Geometry::IMAGE);
   CompareMsgsGeometryTypeToString(msgs::Geometry::HEIGHTMAP);
